<!--img src="ex_u.jpg" width="75%"-->


# kars: Kernel Approximation of Raman Spectra

`kars` is a python package for kernel approximations to spectra, and in particular, coherent-antistokes raman spectroscopy. For example `kars` can create quick approximations using library of output spectra from CARSFT. 

## Software

* Our **python package** `kars` is available on [pypi](https://pypi.org/project/kars/).

### Vignettes

* A basic vignette of how to use `kars` with a library of CARSFT data is available in as [jupyter notebook](examples/test.ipynb) | [python script](examples/test.py) | [markdown](examples/test.md) | [html](examples/test.html)
* The data is available here: [spectra.csv](examples/spectra.csv) [params.csv](examples/params.csv) [wn.csv](examples/wn.csv)

## Papers

### 1. "Adaptive Modeling Powers Fast Multi-parameter Fitting of CARS Spectra" 

* Our **publication** is available on arXiv [here](https://arxiv.org/abs/2111.00917)